@@ -91,6 +91,8 @@ class Limiter(object):
      down.
     :param bool in_memory_fallback_enabled: simply falls back to in memory
      storage when the main storage is down and inherits the original limits.
+    :param str retry_after: Allows configuration of how the value of the
+     `Retry-After` header is rendered. One of `http-date` or `delta-seconds`.
     :param str key_prefix: prefix prepended to rate limiter keys.
     """
 
@@ -120,6 +122,7 @@ class Limiter(object):
         self.logger = logging.getLogger("flask-limiter")
 
         self.enabled = enabled
+        self.initialized = False
         self._default_limits = []
         self._default_limits_per_method = default_limits_per_method
         self._default_limits_exempt_when = default_limits_exempt_when
@@ -206,6 +209,9 @@ class Limiter(object):
         """
         config = app.config
         self.enabled = config.setdefault(C.ENABLED, self.enabled)
+        if not self.enabled:
+            return
+
         self._default_limits_per_method = config.setdefault(
             C.DEFAULT_LIMITS_PER_METHOD, self._default_limits_per_method
         )
@@ -307,6 +313,7 @@ class Limiter(object):
             app.after_request(self.__inject_headers)
 
         app.extensions['limiter'] = self
+        self.initialized = True
 
     def __configure_fallbacks(self, app, strategy):
         config = app.config
@@ -373,11 +380,6 @@ class Limiter(object):
         for lim, args in getattr(g, 'conditional_deductions', {}).items():
             if lim.deduct_when(response):
                 self.limiter.hit(lim.limit, *args)
-                if (
-                    not getattr(g, "view_rate_limit")
-                    or lim.limit < g.view_rate_limit[0]
-                ):
-                    g.view_rate_limit = [lim.limit] + args
 
         return response
 
@@ -427,7 +429,7 @@ class Limiter(object):
                 )
             except:  # noqa: E722
                 if self._in_memory_fallback_enabled and not self._storage_dead:
-                    self.logger.warn(
+                    self.logger.warning(
                         "Rate limit storage unreachable - falling back to"
                         " in-memory storage"
                     )
@@ -451,40 +453,42 @@ class Limiter(object):
 
         for lim in limits:
             limit_scope = lim.scope or endpoint
+
             if lim.is_exempt or lim.method_exempt:
                 continue
+
             if lim.per_method:
                 limit_scope += ":%s" % request.method
             limit_key = lim.key_func()
-
             args = [limit_key, limit_scope]
-            if all(args):
-                if self._key_prefix:
-                    args = [self._key_prefix] + args
-
-                if lim.deduct_when:
-                    g.conditional_deductions[lim] = args
-                    method = self.limiter.test
-                else:
-                    if not limit_for_header or lim.limit < limit_for_header[0]:
-                        limit_for_header = [lim.limit] + args
-
-                    method = self.limiter.hit
-
-                if not method(lim.limit, *args):
-                    self.logger.warning(
-                        "ratelimit %s (%s) exceeded at endpoint: %s",
-                        lim.limit, limit_key, limit_scope
-                    )
-                    failed_limit = lim
-                    limit_for_header = [lim.limit] + args
-                    break
-            else:
+            if not all(args):
                 self.logger.error(
                     "Skipping limit: %s. Empty value found in parameters.",
                     lim.limit
                 )
                 continue
+
+            if self._key_prefix:
+                args = [self._key_prefix] + args
+
+            if lim.deduct_when:
+                g.conditional_deductions[lim] = args
+                method = self.limiter.test
+            else:
+                method = self.limiter.hit
+
+            if not limit_for_header or lim.limit < limit_for_header[0]:
+                limit_for_header = [lim.limit] + args
+
+            if not method(lim.limit, *args):
+                self.logger.warning(
+                    "ratelimit %s (%s) exceeded at endpoint: %s",
+                    lim.limit, limit_key, limit_scope
+                )
+                failed_limit = lim
+                limit_for_header = [lim.limit] + args
+                break
+
         g.view_rate_limit = limit_for_header
 
         if failed_limit:
@@ -499,7 +503,7 @@ class Limiter(object):
         )
         if (
             not request.endpoint
-            or not self.enabled
+            or not (self.enabled and self.initialized)
             or view_func == current_app.send_static_file
             or name in self._exempt_routes
             or request.blueprint in self._blueprint_exempt
@@ -611,7 +615,7 @@ class Limiter(object):
             if isinstance(e, RateLimitExceeded):
                 six.reraise(*sys.exc_info())
             if self._in_memory_fallback_enabled and not self._storage_dead:
-                self.logger.warn(
+                self.logger.warning(
                     "Rate limit storage unreachable - falling back to"
                     " in-memory storage"
                 )
@@ -811,7 +815,7 @@ class Limiter(object):
 
     def __raise_global_limits_warning(self):
         warnings.warn(
-            "global_limits was a badly name configuration since it is "
+            "global_limits was a badly named configuration since it is "
             "actually a default limit and not a globally shared limit. Use "
             "default_limits if you want to provide a default or use "
             "application_limits if you intend to really have a global "
